@@ -63,7 +63,7 @@ QString ConfigStrings::OUTPUTDIR = QStringLiteral("outputdir");
 QString ConfigStrings::OUTPUTFORMATS = QStringLiteral("outputformats");
 QString ConfigStrings::OUTPUTPREFIXES = QStringLiteral("outputprefixes");
 QString ConfigStrings::OUTPUTSUFFIXES = QStringLiteral("outputsuffixes");
-QString ConfigStrings::PRODUCTNAME = QStringLiteral("productname");
+QString ConfigStrings::PRODUCTNAME QStringLiteral("productname");
 QString ConfigStrings::PROJECT = QStringLiteral("project");
 QString ConfigStrings::REDIRECTDOCUMENTATIONTODEVNULL =
         QStringLiteral("redirectdocumentationtodevnull");
@@ -71,6 +71,7 @@ QString ConfigStrings::REPORTMISSINGALTTEXTFORIMAGES =
         QStringLiteral("reportmissingalttextforimages");
 QString ConfigStrings::QHP = QStringLiteral("qhp");
 QString ConfigStrings::QUOTINGINFORMATION = QStringLiteral("quotinginformation");
+QString ConfigStrings::ROOTDIR = QStringLiteral("rootdir");
 QString ConfigStrings::SCRIPTS = QStringLiteral("scripts");
 QString ConfigStrings::SHOWINTERNAL = QStringLiteral("showinternal");
 QString ConfigStrings::SINGLEEXEC = QStringLiteral("singleexec");
@@ -358,6 +359,7 @@ void Config::clear()
     m_configVars.clear();
     m_includeFilesMap.clear();
     m_excludedPaths.reset();
+    m_sourceLink.reset();
 }
 
 /*!
@@ -416,6 +418,10 @@ void Config::load(const QString &fileName)
     else
         m_location.setEtc(true);
 
+    // Resolve variables that are interpreted as paths
+    QString varName{CONFIG_URL + dot + CONFIG_SOURCES + dot + CONFIG_ROOTDIR};
+    setStringList(varName, getCanonicalPathList(varName, Validate));
+
     expandVariables();
 
     // Add defines and includepaths from command line to their
@@ -1296,7 +1302,7 @@ void Config::load(Location location, const QString &fileName)
                         if (!var.isEmpty()) {
                             const QByteArray val = qgetenv(var.toLatin1().constData());
                             if (val.isNull()) {
-                                expandVars << ExpandVar(rhsValues.size(), word.size(), var, delim);
+                                expandVars << ExpandVar(rhsValues.size(), word.size(), std::move(var), delim);
                                 needsExpansion = true;
                             } else if (braces) { // ${VAR} inserts content from an env. variable for processing
                                 text.insert(i, QString::fromLatin1(val));
@@ -1418,11 +1424,31 @@ const Config::ExcludedPaths& Config::getExcludedPaths() {
     QSet<QString> excludedDirs = QSet<QString>(excludedDirList.cbegin(), excludedDirList.cend());
     QSet<QString> excludedFiles = QSet<QString>(excludedFilesList.cbegin(), excludedFilesList.cend());
 
-    m_excludedPaths.emplace(ExcludedPaths{excludedDirs, excludedFiles});
+    m_excludedPaths.emplace(ExcludedPaths{std::move(excludedDirs), std::move(excludedFiles)});
 
     return *m_excludedPaths;
 }
 
+/*!
+    Returns a SourceLink struct with settings required to
+    construct source links to API entities.
+*/
+const Config::SourceLink &Config::getSourceLink()
+{
+    if (m_sourceLink)
+        return *m_sourceLink;
+
+    const auto srcUrl{CONFIG_URL + Config::dot + CONFIG_SOURCES};
+
+    const auto baseUrl = m_configVars.value(srcUrl).asString();
+    const auto rootPath = m_configVars.value(srcUrl + dot + CONFIG_ROOTDIR).asString();
+    const auto linkText = m_configVars.value(srcUrl + dot + "linktext").asString();
+    const auto enabled = m_configVars.value(srcUrl + dot + "enabled").asBool();
+
+    m_sourceLink.emplace(SourceLink{baseUrl, rootPath, linkText, enabled});
+    return *m_sourceLink;
+}
+
 std::set<Config::HeaderFilePath> Config::getHeaderFiles() {
     static QStringList accepted_header_file_extensions{
         "ch", "h", "h++", "hh", "hpp", "hxx"
